client_request_extend

Function client_request_extend 

pub fn client_request_extend<B>(req: &mut Request<B>)
Extend a Request with websocket associated headers and methods. After extension the request would be ready to be sent to server.

HTTP/2 specific behavior

For HTTP/2 websocket a Http2WsProtocol type is injected into Extensions It can be used for extending protocol pseudo header for :protocol